# Code written by Prof. John Gallaugher, modified by Mike Dolan for Bills project box
# Adafruit Circuit Playground Express Bluefruit

import time
import board
import digitalio
import neopixel

from adafruit_ble import BLERadio
from adafruit_ble.advertising.standard import ProvideServicesAdvertisement
from adafruit_ble.services.nordic import UARTService

from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile

from adafruit_bluefruit_connect.packet import Packet
from adafruit_bluefruit_connect.color_packet import ColorPacket
from adafruit_bluefruit_connect.button_packet import ButtonPacket

# setup pixels
pixels = neopixel.NeoPixel(board.NEOPIXEL, 10, brightness=1, auto_write=True)

# name colors so you don't need to refer to numbers
RED = (255, 0, 0)
ORANGE = (255, 50, 0)
BLACK = (0, 0, 0)
GREEN = (0, 255, 0)
PURPLE = (100, 0, 255)
YELLOW = (255,230, 0)
BLUE = (0, 0, 255)
WHITE= (255, 255, 255)
# setup bluetooth
ble = BLERadio()
uart_service = UARTService()
advertisement = ProvideServicesAdvertisement(uart_service)

# External Audio Stuff
speaker_enable = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker_enable.direction = digitalio.Direction.OUTPUT
speaker_enable.value = True

audio = AudioOut(board.SPEAKER)  # Speaker
wave_file = None

def play_wav(name, loop=False):
    """
    Play a WAV file in the 'sounds' directory.
    :param name: partial file name string, complete name will be built around
                 this, e.g. passing 'foo' will play file 'sounds/foo.wav'.
    :param loop: if True, sound will repeat indefinitely (until interrupted
                 by another sound).
    """
    global wave_file  # pylint: disable=global-statement
    print("playing", name)
    if wave_file:
        wave_file.close()
    try:
        wave_file = open('sounds/' + name + '.wav', 'rb') # using wave files from sounds folder
        wave = WaveFile(wave_file)
        audio.play(wave, loop=loop)
    except OSError:
        pass # we'll just skip playing then

while True:
    # set CPXb up so that it can be discovered by the app
    ble.start_advertising(advertisement)
    while not ble.connected:
        pass

    # Now we're connected

    while ble.connected:

        if uart_service.in_waiting:
            try:
                packet = Packet.from_stream(uart_service)
            except ValueError:
                continue # or pass.

            if isinstance(packet, ColorPacket): # check if a color was sent from color picker
                pixels.fill(packet.color)
            if isinstance(packet, ButtonPacket): # check if a button was pressed from control pad
                if packet.pressed:
                    if packet.button == ButtonPacket.BUTTON_1: # if button #1
                        pixels.fill(BLUE)
                        play_wav("bills")
                        time.sleep(2)
                        pixels.fill(BLACK)
                        pixels.fill(RED)
                        time.sleep(1)
                        pixels.fill(BLACK)
                        pixels.fill(BLUE)
                        time.sleep(2)
                        pixels.fill(WHITE)
                        time.sleep(1)
                        pixels.fill(BLUE)
                        time.sleep(.5)
                        pixels.fill(RED)
                        time.sleep(.5)
                        pixels.fill(WHITE)
                        time.sleep(1)
                        pixels.fill(RED)
                        time.sleep(1)
                        pixels.fill(BLUE)
                        time.sleep(2)
                        pixels.fill(WHITE)
                        time.sleep(1)
                        pixels.fill(RED)
                        time.sleep(1.5)
                        pixels.fill(BLUE)
                        time.sleep(2.25)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.BUTTON_2: # if button #2
                        pixels.fill(RED)
                        play_wav("td")
                        time.sleep(3)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.BUTTON_3: # if button #3
                        pixels.fill(YELLOW)
                        play_wav("fumble")
                        time.sleep(3.2)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.BUTTON_4: # if button #4
                        pixels.fill(GREEN)
                        play_wav("firstdown")
                        time.sleep(1)
                        pixels.fill(WHITE)
                        time.sleep(1)
                        pixels.fill(GREEN)
                        time.sleep(1)
                        pixels.fill(WHITE)
                        time.sleep(1)
                        pixels.fill(GREEN)
                        time.sleep(1)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.UP: # if button UP
                        pixels.fill(GREEN)
                        play_wav("fgoal")
                        time.sleep(2.8)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.DOWN: # if button DOWN
                        pixels.fill(PURPLE)
                        play_wav("tackle")
                        time.sleep(3)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.LEFT: # if button LEFT
                        pixels.fill(RED)
                        time.sleep(.5)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLUE)
                        time.sleep(.5)
                        pixels.fill(RED)
                        time.sleep(.5)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLUE)
                        time.sleep(.5)
                        pixels.fill(BLACK)
                        pixels.fill(RED)
                        time.sleep(.5)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLUE)
                        time.sleep(.5)
                        pixels.fill(RED)
                        time.sleep(.5)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLUE)
                        time.sleep(.5)
                        pixels.fill(BLACK)
                    if packet.button == ButtonPacket.RIGHT: # if button RIGHT
                        pixels.fill(BLUE)
                        time.sleep(.25)
                        pixels.fill(RED)
                        time.sleep(.25)
                        pixels.fill(WHITE)
                        time.sleep(.25)
                        pixels.fill(RED)
                        time.sleep(.25)
                        pixels.fill(BLUE)
                        time.sleep(.25)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLACK)
                        pixels.fill(BLUE)
                        time.sleep(.25)
                        pixels.fill(RED)
                        time.sleep(.25)
                        pixels.fill(WHITE)
                        time.sleep(.25)
                        pixels.fill(RED)
                        time.sleep(.25)
                        pixels.fill(BLUE)
                        time.sleep(.25)
                        pixels.fill(WHITE)
                        time.sleep(.5)
                        pixels.fill(BLACK)